.. DHNx documentation master file, created by
   sphinx-quickstart on Mon Jan 13 15:33:34 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to DHNx's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Getting started

   getting_started
   examples


.. toctree::
   :maxdepth: 2
   :caption: User's guide

   network
   geometry_preparation
   optimization_models
   simulation_models
   model_coupling
   analyze_and_plot


.. toctree::
   :maxdepth: 2
   :caption: Reference

   api
   whats_new
   authors


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
